@@ -1,6 +1,6 @@
 /* PROM Node Operations interface
  *
- * (C) Copyright 2011 Frontgrade Gaisler
+ * (C) Copyright 2011 Aeroflex Gaisler
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -48,7 +48,6 @@ struct prop {
 #define PO_DATA		0x0000
 #define PO_PTR		0x4000
 #define PO_END		0x2000 /* End of Array/List */
-#define PO_REMOVED	0x1000 /* Property is considered removed */
 #define PO_TYPE_MASK	0x00ff /* Custom Node Type Number goes here (N/A) */
 
 struct prop_std {
@@ -100,43 +99,6 @@ struct propa_ptr {
 #define PROPA_INT_END(name, i) \
 	{PO_NONEXT|PO_DATA|PO_END, 4, name, (void *)i}
 
-/* xml extra macros and data structures */
-#define PROPA_RM(name) \
-	{PO_NONEXT|PO_PTR|PO_REMOVED, 0, name, NULL}
-#define PROPA_RM_END(name) \
-	{PO_NONEXT|PO_PTR|PO_REMOVED|PO_END, 0, name, NULL}
-
-/* Is set when xml_node is a placeholder node */
-#define XMLNODE_PLH 0x1
-
-struct xml_node {
-	struct node node;
-	short propcount;
-	int nhtarget_start;
-	int nhtarget_count;
-	int flags;
-};
-
-#define XMLMATCH_CORE	0x001
-#define XMLMATCH_BUS	0x002
-#define XMLMATCH_REMOVE	0x100
-#define XMLMATCH_ROOT	0x1000
-
-struct xml_match {
-	/* Mathing cores */
-	int vendor;
-	int device;
-	int index;
-	int coreindex;
-
-	/* Matching buses */
-	int bus;
-
-	/* General fields */
-	int flags;
-	int placeholder;
-};
-
 /* PROM Node Operations Called from Linux */
 extern int no_nextnode(int node);
 extern int no_child(int node);
@@ -147,9 +109,5 @@ extern char *no_nextprop(int node, char *name);
 
 /* PROM Edit Device Structures (prior to booting Linux) */
 extern void prop_add(struct node *n, struct prop *newprop);
-extern void prop_del(struct node *n, char *name);
-extern void prop_add_dup(struct node *n, struct prop_std *buf,
-			  int size, struct prop_std **lastprop);
-extern void node_add_child(struct node *node, struct node *child);
 
 #endif
