@@ -1,7 +1,7 @@
 /* Early boot code. Setup CPU, MMU tables and prepare STARTUP/PROM environment.
  * Most code here are executed in physical address space.
  *
- * Copyright (C) 2011 Frontgrade Gaisler AB
+ * Copyright (C) 2011 Aeroflex Gaisler AB
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -22,9 +22,6 @@
 #include <common.h>
 #include <linkscript.h>
 
-#ifdef CONFIG_WATCHDOG
-#include <prom_watchdog.h>
-#endif
 /* Must not be overwritten by BSS clearer */
 int __attribute__((section(".data"))) first_cpu_booted = 0;
 unsigned long __attribute__((section(".data"))) end_of_mem; /* Set by head.S */
@@ -32,14 +29,12 @@ unsigned long __attribute__((section(".data"))) end_of_mem; /* Set by head.S */
 unsigned long start_ffd00000_pa;
 
 /* Common Data, initialized by startup_prom_init */
-struct common_data *pcommon = 0;
+struct common_data *pcommon;
 
 static inline __attribute__((always_inline))
 void srmmu_set_mmureg(unsigned long regval)
 {
-	__asm__ __volatile__(B2B_INLINE_DOUBLE_NOP
-			     "sta %0, [%%g0] %1\n\t"
-			     B2B_INLINE_DOUBLE_NOP : :
+	__asm__ __volatile__("sta %0, [%%g0] %1\n\t" : :
 			     "r" (regval), "i" (0x19) : "memory");
 
 }
@@ -58,9 +53,7 @@ static inline __attribute__((always_inline))
 void srmmu_set_ctable_ptr(unsigned long paddr)
 {
 	paddr = ((paddr >> 4) & 0xfffffff0);
-	__asm__ __volatile__(B2B_INLINE_DOUBLE_NOP
-			     "sta %0, [%1] %2\n\t"
-			     B2B_INLINE_DOUBLE_NOP : :
+	__asm__ __volatile__("sta %0, [%1] %2\n\t" : :
 			     "r" (paddr), "r" (0x00000100),
 			     "i" (0x19) :
 			     "memory");
@@ -69,9 +62,7 @@ void srmmu_set_ctable_ptr(unsigned long paddr)
 static inline __attribute__((always_inline))
 void srmmu_set_context(int context)
 {
-	__asm__ __volatile__(B2B_INLINE_DOUBLE_NOP
-			     "sta %0, [%1] %2\n\t"
-			     B2B_INLINE_DOUBLE_NOP : :
+	__asm__ __volatile__("sta %0, [%1] %2\n\t" : :
 			     "r" (context), "r" (0x00000200),
 			     "i" (0x19) : "memory");
 }
@@ -81,9 +72,7 @@ static inline __attribute__((always_inline)) void leon3_enable_snooping(void)
 	__asm__ __volatile__ ("lda [%%g0] 2, %%l1\n\t"
 			      "set 0x800000, %%l2\n\t"
 			      "or  %%l2, %%l1, %%l2\n\t"
-			      "sta %%l2, [%%g0] 2\n\t"
-			      B2B_INLINE_DOUBLE_NOP
-			      : : : "l1", "l2");
+			      "sta %%l2, [%%g0] 2\n\t" : : : "l1", "l2");
 }
 
 static inline int leon3_processor_id(void)
@@ -102,20 +91,15 @@ static inline void set_tbr(unsigned long regval)
 
 static inline void leon_flush_cache_all(void)
 {
-	__asm__ __volatile__("flush\n\t" /* iflush */
-			     B2B_INLINE_SINGLE_NOP
-			     "sta %%g0, [%%g0] %0\n\t"
-			     B2B_INLINE_DOUBLE_NOP : :
+	__asm__ __volatile__(" flush ");	/*iflush */
+	__asm__ __volatile__("sta %%g0, [%%g0] %0\n\t" : :
 			     "i"(ASI_LEON_DFLUSH) : "memory");
 }
 
 static inline void leon_flush_tlb_all(void)
 {
 	leon_flush_cache_all();
-	__asm__ __volatile__(B2B_INLINE_DOUBLE_NOP
-			     "sta %%g0, [%0] %1\n\t"
-			     B2B_INLINE_DOUBLE_NOP
-			     : : "r"(0x400),
+	__asm__ __volatile__("sta %%g0, [%0] %1\n\t" : : "r"(0x400),
 			     "i"(ASI_LEON_MMUFLUSH) : "memory");
 }
 
@@ -139,24 +123,6 @@ void cache_init(void)
 	leon3_enable_snooping();
 }
 
-void fpu_init(void)
-{
-	/*
-	 * Disable the FPU - This gives early warning of violations against the
-	 * policy that mklinuximg should support systems with no FPU without
-	 * need for soft floats.
-	 */
-	__asm__ __volatile__ ("mov %%psr, %%l1\n\t"
-			      "set 0x1000, %%l2\n\t"
-			      "not %%l2, %%l2\n\t"
-			      "and %%l1, %%l2, %%l1\n\t"
-			      "mov %%l1, %%psr\n\t"
-			      "nop\n\t"
-			      "nop\n\t"
-			      "nop\n\t"
-			      : : : "l1", "l2");
-}
-
 /* The Below Code sets up the Virtual Address Space as follows:
  *
  * Only Context 0 valid. Context 0 address map using 3 levels:
@@ -291,8 +257,6 @@ int boot_main(int arg0, int arg1, int arg2)
 
 	cache_init();
 
-	fpu_init();
-
 	/* Only Master CPU initialize early MMU Table */
 	if (first_cpu_booted == 0)
 		mmu_table_init();
@@ -347,11 +311,6 @@ void boot_kernel(void)
 {
 	void (*kernel)(int arg0, int arg1);
 
-#ifdef CONFIG_WATCHDOG
-	/* Ping watchdog before booting Linux */
-	watchdog_ping(PING_ID_BOOT);
-#endif
-
 	/* Boot into Linux kernel (Virtual Address). Assume Reset-trap vector
 	 * is entry point.
 	 */
@@ -363,7 +322,3 @@ void boot_kernel(void)
 	kernel(pcommon->karg0, pcommon->karg1);
 #endif
 }
-
-#ifdef FORCE_GRMON_LOAD_SYM
-char _force_grmon_load_sym[] = FORCE_GRMON_LOAD_SYM;
-#endif
