@@ -1,6 +1,6 @@
 /* AMBA definitions resident in PROM
  *
- * Copyright (C) 2011 Frontgrade Gaisler AB
+ * Copyright (C) 2011 Aeroflex Gaisler AB
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -33,39 +33,6 @@ char *prop_str_index = "index";
 char *prop_str_ampopts = "ampopts";
 char *prop_str_description = "description";
 
-/* Linux specific AMBA Property Names */
-char *prop_str_compatible = "compatible";
-char *prop_str_clockfrequency = "clock-frequency";
-
-#ifdef CONFIG_WATCHDOG
-/* Linux specific watchdog property names */
-char *prop_str_watchdog = "watchdog";
-char *prop_str_timeout_sec = "timeout-sec";
-char *prop_str_hw_timeout_ms = "gaisler,max-hw-timeout-ms";
-#endif
-
-/* Linux common clock framework properties */
-
-/* Clock producer properties */
-char *prop_str_clock_cells = "#clock-cells";
-char *prop_str_clock_output_names = "clock-output-names";
-char *prop_str_protected_clocks = "protected-clocks";
-char *prop_str_clock_indices = "clock-indices";
-
-/* Clock consumer properties: */
-char *prop_str_clocks = "clocks";
-char *prop_str_clock_names = "clock-names";
-
-#ifdef CONFIG_HRTIMERS
-char *prop_str_cs_tmr_idx = "gaisler,cs-timer-idx";
-char *prop_str_tmr_offset = "gaisler,timer-offset";
-char *prop_str_tmr_len = "gaisler,timer-len";
-char *prop_str_cpu_offset = "gaisler,cpu-offset";
-char *prop_str_compatible_timer = "gaisler,gptimer-timer";
-char *prop_str_compatible_timer_cs = "gaisler,gptimer-timer-cs";
-char *prop_str_compatible_timer_ce = "gaisler,gptimer-timer-ce";
-#endif
-
 #ifdef CONFIG_CUSTOM_NODES
 /* Example for how to create a custom AMBA node tree. This was tested on a
  * GR712 Evaluation Board at 80MHz.
@@ -136,7 +103,7 @@ struct node nodes_amba[] = {
 
 struct node *pnodes_amba = &nodes_amba[0];
 
-void ambapp_nodes_init(struct node *n)
+void ambapp_nodes_init(void)
 {
 
 }
