@@ -1,7 +1,7 @@
 /* Example for how to create a custom AMBA node tree. This was tested on a
  * GR712 Evaluation Board at 80MHz.
  *
- * Copyright (C) 2011 Frontgrade Gaisler AB
+ * Copyright (C) 2011 Aeroflex Gaisler AB
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -92,7 +92,7 @@ struct node nodes_amba[] = {
 
 struct node *pnodes_amba = &nodes_amba[0];
 
-void ambapp_nodes_init(struct node *n)
+void ambapp_nodes_init(void)
 {
 	cpu_freq_khz = SYSTEM_FREQ_HZ / 1000;
 
